from typing import Any, List, Optional
import subprocess
from fastapi import UploadFile, File, Form
from fastapi.responses import FileResponse
from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session

import app.crud as crud
import app.models as models
import app.schemas as schemas 
from app.api import deps

from app.core.celery_app import celery_app
from app.core.config import settings
from pathlib import Path
from app.utils import random_name

from app.core.celery_app import celery_app

BACKEND_ZIP_STORAGE = Path("/app").joinpath(settings.BACKEND_ZIP_STORAGE)
LOCAL_ZIP_STORAGE = Path("/").joinpath(settings.LOCAL_ZIP_STORAGE)


router = APIRouter()



@router.post("/sr")
async def supser_resolution(
    *,
    db: Session = Depends(deps.get_db),
    current_user: models.User = Depends(deps.get_current_active_user),
    upload_files: List[UploadFile]=File(description="Multiple files as UploadFile"),
) -> Any:
    """
    Super Resolution.
    """
    filenames = [random_name(20) for file in upload_files]
    return {"filenames": filenames}

@router.get("/sr")
def get_image(
    *,
    db: Session = Depends(deps.get_db),
    current_user: models.User = Depends(deps.get_current_active_user),
    stored_file_name: str,
    file_name: str,
) -> Any:
    """
    Download image
    """
    filename = Path(file_name)
    response_filename = filename.stem + "_hr.png"
    return FileResponse(path="test_medias/superman_resolution.png", media_type='image/png', filename=response_filename)

